#!/bin/bash
#

# need an in source build

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
}


get_platform_name()
{
    OS1=`uname`
    flvr=`ups flavor`
    if [ ${OS1} = "Darwin" ]
    then
      (( darwin = 1 ))
      flvr=`ups flavor -2`
    fi
    OS=`${SSIBUILDSHIMS_DIR}/bin/get_os_platform`
    plat=`${SSIBUILDSHIMS_DIR}/bin/get_os_platform osplat`

    if [ -z ${flvr} ]
    then
       echo "ERROR: could not determine flavor for this platform"
       echo "       something is very wrong"
       exit 1
    fi

    pkgdir=${product_dir}/${package}/${pkgver}/${flvr}
    patchdir=${product_dir}/${package}/${pkgver}/patch
    tardir=${product_dir}/${package}/${pkgver}/tar
    sourcedir=${product_dir}/${package}/${pkgver}/source
}

die()
{
  echo "$1"; exit 2
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
maketar=${2}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=libwda
origpkgver=v2_21_1
pkgver=${origpkgver}
#pkgver=`echo ${origpkgver} | sed -e 's/wda_//'`
ssibuildshims_version=v0_08_06
pkgtarfile=ifdhc-${package}.${origpkgver}.tbz2

get_this_dir

get_ssibuildshims

get_platform_name

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_QUAL
   exit 0
fi

echo "building ${package} for ${OS}-${plat} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

mkdir -p ${pkgdir}/libwda
if [ ! -d ${pkgdir}/libwda ]
then
   echo "ERROR: failed to create ${pkgdir}/libwda"
   exit 1
fi

cd ${pkgdir}/libwda  || die "ERROR: could not cd ${pkgdir}/libwda"
tar xf ${tardir}/${pkgtarfile} || die "ERROR: failed to unwind ${pkgtarfile}"
patch -b -p0 < "${patchdir}/libwda.patch" || die "ERROR: application of patch ${patch} failed."
set -x

cd ${pkgdir}/libwda/src

make LIBWDA_VERSION=${origpkgver} all || die "ERROR: make all failed"
make PREFIX=${pkgdir} install || die "ERROR: make install failed"
make clean || die "ERROR: make clean failed"

cd ${pkgdir} 
cp -pr libwda/ups ../ups

set +x

if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi


# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} NO_QUAL

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -z ${product_dir} || die "ERROR: setup failed"

# this must be last
if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_QUAL
fi

exit 0
